namespace Vha.Vss.Utility
{
	using System;
  using System.Collections.Specialized;
	/// <summary>
  ///Provides sorted collection of associated string keys and Object values that can 
  ///be accessed either with the hash code of the key or with the index
  /// </summary>
  public class NameObjectCollection : System.Collections.Specialized.NameObjectCollectionBase , IDisposable
	{
    ///<summary>
    ///Gets or sets a value indicating whether the NameObjectCollection instance is read-only.
    ///</summary>
    ///<remarks>
    ///true if the NameObjectCollection instance is read-only; otherwise, false.
    ///</remarks>
    ///<Examples>
    ///<example language="C#">
    ///<code>
    ///NameObjectCollection myCollection = new NameObjectCollection();
    ///myCollection.Add("Item1",myObject1);
    ///myCollection.Add("Item2",myObject2);
    ///myCollection.Add("Item3",myObject3);
    ///myCollection.Add("Item4",myObject4);
    ///myCollection.ReadOnly = true;
    ///</code>
    ///</example>
    ///</Examples>
    public  bool ReadOnly 
    {
      get {return base.IsReadOnly;} 

      set {base.IsReadOnly = value;}
    }
    ///<summary>
    ///Default constructor that takes no arguments.  The collection will be initialized with default 
    ///capacity of zero.  The capacity will be increased as required.
    ///</summary>
    ///<Params>None
    ///</Params>
    ///<remarks>
    ///</remarks>
    ///<Examples>
    /// <example language="C#">
    ///<code>
    ///NameObjectCollection objCollection = new NameObjectCollection();
    ///</code>
    /// </example>
    ///</Examples>
    ///<References>
    /// <seealso cref="NameObjectCollection(int)"/>
    ///</References>
    public NameObjectCollection() 
    {
    }

    
    ///<summary>
    ///Initializes a new instance of the NameObjectCollection class that is empty and has the specified initial capacity
    ///</summary>
    ///<Params>
    ///  <param type="System.int" name="capacity" Required="">
    ///  Contains the initial capacity of the collection.
    ///  </param>
    ///</Params>
    ///<remarks>
    ///Use this constructor to initialize the collection with a given capacity
    ///</remarks>
    ///<Examples>
    /// <example language="C#">
    ///<code>
    ///NameObjectCollection objCollection = new NameObjectCollection(100);
    ///</code>
    /// </example>
    ///</Examples>
    ///<Exceptions>
    ///<Table col1="Exception" col2="Description">
    ///<Row col1="ArgumentOutOfRangeException" col2="capacity is less than zero"/>
    ///</Table>
    ///</Exceptions>
    ///<References>
    /// <seealso cref="NameObjectCollection(int)"/>
    ///</References>
    public NameObjectCollection(int capacity) : base(capacity)
		{

		}
    
    /// <summary>NameObjectCollection implements INameObjectCollection</summary>
    ~NameObjectCollection()
    {
      BaseClear();
    }

    ///<summary>
    ///Adds an entry with the specified name and value to the NameObjectCollection instance 
    ///</summary>
    ///<Params>
    ///<param type="String" name="name" Required="Mandatory">
    ///<para>
    ///The string key of the entry to add
    ///</para>
    ///</param>
    ///<param type="Object" name="value" Required="Mandatory">
    ///<para>
    ///The Object value of the entry to add.
    ///</para>
    ///</param>
    ///</Params>
    ///<returns type="void">
    ///</returns>
    ///<remarks>
    ///Use this function to add a new element to the NameObjectCollection
    ///</remarks>
    ///<Examples>
    /// <example language="C#">
    ///<code>
    ///NameObjectCollection objCollection = new NameObjectCollection(100);
    ///objCollection.Add("Item1",myObject);
    ///</code>
    /// </example>
    ///</Examples>
    ///<Exceptions>
    ///<Table col1="Exception" col2="Description">
    ///<Row col1="NotSupportedException" col2="The collection is read-only"/>
    ///</Table>
    ///</Exceptions>
    ///<References>
    /// <seealso cref="NameObjectCollection.Set(string,Object)"/>
    /// <seealso cref="NameObjectCollection.Set(int,Object)"/>
    ///</References>
    public void Add(string name, Object value) 
    {
        BaseAdd(name,value);
    }

    ///<summary>
    ///Sets an entry with the specified name and value 
    ///</summary>
    ///<Params>
    ///<param type="String" name="name" Required="Mandatory">
    ///<para>
    ///The String key of the entry to set
    ///</para>
    ///</param>
    ///<param type="Object" name="value" Required="Mandatory">
    ///<para>
    ///The Object value of the entry to set.
    ///</para>
    ///</param>
    ///</Params>
    ///<returns type="void">
    ///</returns>
    ///<remarks>
    ///Use this function to replace an existing element with a new element in the NameObjectCollection instance.
    ///If the collection contains multiple entries with the specified key, this method sets only the first entry.
    ///To set the values of subsequent entries with the same key, use the enumerator to iterate through the 
    ///collection and compare the keys.
    ///</remarks>
    ///<Examples>
    /// <example language="C#">
    ///<code>
    ///objCollection.Set("Item1",myObject);
    ///</code>
    /// </example>
    ///</Examples>
    ///<Exceptions>
    ///<Table col1="Exception" col2="Description">
    ///<Row col1="NotSupportedException" col2="The collection is read-only"/>
    ///</Table>
    ///</Exceptions>
    ///<References>
    /// <seealso cref="NameObjectCollection.Set(int,Object)"/>
    ///</References>
    public void Set(string name, Object value) 
    {
      BaseSet(name,value);
    }

    ///<summary>
    ///Sets a new elements at the specified index 
    ///</summary>
    ///<Params>
    ///<param type="int" name="index" Required="Mandatory">
    ///<para>
    ///The integer index for which to set the value
    ///</para>
    ///</param>
    ///<param type="Object" name="value" Required="Mandatory">
    ///<para>
    ///The Object value of the entry to set.
    ///</para>
    ///</param>
    ///</Params>
    ///<returns type="void">
    ///</returns>
    ///<remarks>
    ///Use this function to replace an existing element with a new element in the NameObjectCollection instance.
    ///If the collection contains multiple entries with the specified key, this method sets only the first entry.
    ///To set the values of subsequent entries with the same key, use the enumerator to iterate through the 
    ///collection and compare the keys.
    ///</remarks>
    ///<Examples>
    /// <example language="C#">
    ///<code>
    ///objCollection.Set(1,myObject);
    ///</code>
    /// </example>
    ///</Examples>
    ///<Exceptions>
    ///<Table col1="Exception" col2="Description">
    ///<Row col1="ArgumentOutOfRangeException" col2="index is outside the valid range of indexes for the collection."/>
    ///<Row col1="NotSupportedException" col2="The collection is read-only"/>
    ///</Table>
    ///</Exceptions>
    ///<References>
    /// <seealso cref="NameObjectCollection.Set(string,Object)"/>
    ///</References>
    public void Set(int index, Object value) 
    {
      BaseSet(index,value);
    }

    ///<summary>
    ///Removes the entries with the specified key from the NameObjectCollectionBase instance
    ///</summary>
    ///<Params>
    ///<param type="String" name="name" Required="Mandatory">
    ///<para>
    ///The String key of the entries to remove. The key can be a null reference 
    ///</para>
    ///</param>
    ///</Params>
    ///<returns type="void">
    ///</returns>
    ///<remarks>
    ///Use this function to remove an existing element from the NameObjectCollection
    ///</remarks>
    ///<Examples>
    /// <example language="C#">
    ///<code>
    ///objCollection.Remove("Item1");
    ///</code>
    /// </example>
    ///</Examples>
    ///<Exceptions>
    ///<Table col1="Exception" col2="Description">
    ///<Row col1="ArgumentOutOfRangeException" col2="index is outside the valid range of indexes for the collection."/>
    ///<Row col1="NotSupportedException" col2="The collection is read-only"/>
    ///</Table>
    ///</Exceptions>
    ///<References>
    /// <seealso cref="NameObjectCollection.Remove(int)"/>
    ///</References>
    public void Remove(string name)
    {
      BaseRemove(name);
    }

    ///<summary>
    ///Removes an existing element at the specified index
    ///</summary>
    ///<Params>
    ///<param type="int" name="index" Required="Mandatory">
    ///<para>
    ///The integer index to remove the entry
    ///</para>
    ///</param>
    ///</Params>
    ///<returns type="void">
    ///</returns>
    ///<remarks>
    ///Use this function to remove an existing element from the NameObjectCollection using integer index
    ///</remarks>
    ///<Examples>
    /// <example language="C#">
    ///<code>
    ///objCollection.Remove(1);
    ///</code>
    /// </example>
    ///</Examples>
    ///<Exceptions>
    ///<Table col1="Exception" col2="Description">
    ///<Row col1="ArgumentOutOfRangeException" col2="index is outside the valid range of indexes for the collection."/>
    ///<Row col1="NotSupportedException" col2="The collection is read-only"/>
    ///</Table>
    ///</Exceptions>
    ///<References>
    /// <seealso cref="NameObjectCollection.Remove(string)"/>
    ///</References>
    public void Remove(int index)
    {
      BaseRemoveAt(index);
    }



    ///<summary>
    ///Gets the value of the first entry with the specified key from the NameObjectCollection instance
    ///</summary>
    ///<Params>
    ///<param type="String" name="name" Required="Mandatory">
    ///<para>
    ///The String key of the entry to get. The key can be a null reference
    ///</para>
    ///</param>
    ///</Params>
    ///<returns type="Object">
    ///</returns>
    ///<remarks>
    ///<para>
    ///If the collection contains multiple entries with the specified key, this method returns only the 
    ///first entry. To get the values of subsequent entries with the same key, use the enumerator to iterate 
    ///through the collection and compare the keys
    ///</para>
    ///<para>
    ///This method returns a null reference (Nothing in Visual Basic) in the following cases: 
    ///1) if the specified key is not found; and 
    ///2) if the specified key is found and its associated value is a null reference . 
    ///</para>
    ///</remarks>
    ///<Examples>
    ///<example language="C#">
    ///<code>
    ///Object myObject = objCollection.Get("Item1");
    ///</code>
    /// </example>
    ///</Examples>
    ///<References>
    /// <seealso cref="NameObjectCollection.Get(int)"/>
    ///</References>
    public Object Get(string name)
    {
      return BaseGet(name);
    }

    ///<summary>
    ///Gets the value of the entry at the specified index of the NameObjectCollection instance.
    ///</summary>
    ///<Params>
    ///<param type="int" name="index" Required="Mandatory">
    ///<para>
    ///The zero-based index of the value to get.
    ///</para>
    ///</param>
    ///</Params>
    ///<returns type="Object">
    ///</returns>
    ///<remarks>
    ///<para>
    ///This method returns a null reference (Nothing in Visual Basic) in the following cases: 
    ///1) if the specified key is not found; and 
    ///2) if the specified key is found and its associated value is a null reference . 
    ///</para>
    ///</remarks>
    ///<Examples>
    ///<example language="C#">
    ///<code>
    ///Object myObject = objCollection.Get(1);
    ///</code>
    /// </example>
    ///</Examples>
    ///<Exceptions>
    ///<Table col1="Exception" col2="Description">
    ///<Row col1="ArgumentOutOfRangeException" col2="index is outside the valid range of indexes for the collection."/>
    ///</Table>
    ///</Exceptions>
    ///<References>
    /// <seealso cref="NameObjectCollection.Get(string)"/>
    ///</References>
    public Object Get(int index)
    {
      return BaseGet(index);
    }

    ///<summary>
    ///Returns an Object array that contains all the values in the NameObjectCollection instance.
    ///</summary>
    ///<Params>
    ///</Params>
    ///<returns type="object[]">
    ///</returns>
    ///<remarks>
    ///Use this function to retrieve all values from the NameObjectCollection instance
    ///</remarks>
    ///<Examples>
    ///<example language="C#">
    ///<code>
    ///Object[] arrObj = objCollection.GetAllValues();
    ///</code>
    /// </example>
    ///</Examples>
    ///<References>
    /// <seealso cref="NameObjectCollection.GetAllValues(Type)"/>
    ///</References>
    public object[] GetAllValues()
    {
        return BaseGetAllValues();
    }

    ///<summary>
    ///Returns an array of the specified type that contains all the values in the NameObjectCollection instance.
    ///</summary>
    ///<Params>
    ///</Params>
    ///<returns type="object[]">
    ///</returns>
    ///<remarks>
    ///Use this function to retrieve all values from the NameObjectCollection instance
    ///</remarks>
    ///<Examples>
    ///<example language="C#">
    ///<code>
    ///Object[] arrObj = objCollection.GetAllValues(XmlDocument);
    ///</code>
    /// </example>
    ///</Examples>
    ///<Exceptions>
    ///<Table col1="Exception" col2="Description">
    ///<Row col1="ArgumentNullException" col2="type is a null reference"/>
    ///<Row col1="ArgumentException" col2="type is not valid Type"/>
    ///</Table>
    ///</Exceptions>
    ///<References>
    /// <seealso cref="NameObjectCollection.GetAllValues()"/>
    ///</References>
    public object[] GetAllValues(Type type)
    {
      return BaseGetAllValues(type);
    }


    ///<summary>
    ///Gets the key of the entry at the specified index of the NameObjectCollection instance.
    ///</summary>
    ///<Params>
    ///<param type="int" name="index" Required="Mandatory">
    ///<para>
    ///The zero-based index of the value to get.
    ///</para>
    ///</param>
    ///</Params>
    ///<returns type="string">
    ///</returns>
    ///<remarks>
    ///Use this function to retrieve a key from the NameObjectCollection instance with a given index
    ///</remarks>
    ///<Examples>
    ///<example language="C#">
    ///<code>
    ///string key = objCollection.GetKey(1);
    ///</code>
    /// </example>
    ///</Examples>
    ///<Exceptions>
    ///<Table col1="Exception" col2="Description">
    ///<Row col1="ArgumentOutOfRangeException" col2="index is outside the valid range of indexes for the collection."/>
    ///</Table>
    ///</Exceptions>
    ///<References>
    /// <seealso cref="NameObjectCollection.GetAllKeys()"/>
    ///</References>
    public string GetKey(int index)
    {
      return BaseGetKey(index);
    }

    ///<summary>
    ///Returns a String array that contains all the keys in the NameObjectCollection instance
    ///</summary>
    ///<Params>
    ///</Params>
    ///<returns type="string[]">
    ///</returns>
    ///<remarks>
    ///Use this function to retrieve all the keys from the NameObjectCollection instance
    ///</remarks>
    ///<Examples>
    ///<example language="C#">
    ///<code>
    ///string[] keys = objCollection.GetAllKeys();
    ///</code>
    /// </example>
    ///</Examples>
    ///<References>
    /// <seealso cref="NameObjectCollection.GetKey(int)"/>
    ///</References>
    public string[] GetAllKeys()
    {
      return BaseGetAllKeys();
    }


    ///<summary>
    ///Removes all entries from the NameObjectCollectionBase instance.
    ///</summary>
    ///<Params>
    ///</Params>
    ///<returns type="void">
    ///</returns>
    ///<remarks>
    ///Use this function to clear all existing keys and elements from the NameObjectCollection instance.
    ///After the cleanup the Count is set to zero.
    ///</remarks>
    ///<Examples>
    ///<example language="C#">
    ///<code>
    ///objCollection.Clear();
    ///</code>
    /// </example>
    ///</Examples>
    ///<Exceptions>
    ///<Table col1="Exception" col2="Description">
    ///<Row col1="NotSupportedException" col2="The collection is read-only"/>
    ///</Table>
    ///</Exceptions>
    ///<References>
    /// <seealso cref="NameObjectCollection.GetAllValues()"/>
    ///</References>
    public void Clear()
    {
      BaseClear();
    }

    ///<summary>
    ///Gets a value indicating whether the NameObjectCollection instance contains entries whose keys are not a null reference 
    ///</summary>
    ///<Params>
    ///</Params>
    ///<returns type="bool">
    ///</returns>
    ///<remarks>
    ///Returns true if the NameObjectCollection instance contains entries whose keys are not a null reference.  Returns false otherwise.
    ///</remarks>
    ///<Examples>
    ///<example language="C#">
    ///<code>
    ///bool hasKeys = objCollection.HasKeys();
    ///</code>
    /// </example>
    ///</Examples>
    ///<References>
    /// <seealso cref="NameObjectCollection.GetAllKeys()"/>
    ///</References>
    public bool HasKeys()
    {
      return BaseHasKeys();
    }

    ///<summary>
    ///Cleans up the NameObjectCollection instance resources
    ///</summary>
    ///<Params>
    ///</Params>
    ///<returns type="bool">
    ///</returns>
    ///<remarks>
    ///Use this function to clean NameObjectCollection instance resources
    ///</remarks>
    ///<Examples>
    ///<example language="C#">
    ///<code>
    ///objCollection.Dispose();
    ///</code>
    /// </example>
    ///</Examples>
    ///<References>
    /// <seealso cref="NameObjectCollection.Clear()"/>
    ///</References>
    public void Dispose()
    {
      BaseClear();
      GC.SuppressFinalize(this); 
    }    
  }
}
