using System;
using System.Xml;
using System.Xml.XPath;
using System.Xml.Xsl;
using System.Web;
using System.Web.Security;
using System.Diagnostics;
using Vha.Vss.Security;
using Vha.Vss.Utility;

namespace Vha.Vss.Security
{
	/// <summary>
	/// Summary description for Security.
	/// </summary>
	public class Security
	{
		private string selectedDivision;

		private XmlDocument xmlSecurity;
		private XmlNodeList XmlSecurityList;
		
		private XmlNodeList XmlDivision;
		private XmlDocument xmlDivisionList;
		/// <summary>
		/// Default Constructor For Security
		/// </summary>
		public Security(){}
		/// <summary>
		/// This constructor expects the lists of Divisions and Security to be passed along with the Selected Division.
		/// </summary>
		/// <param name="XmlSecurity" Type="XmlDocument"/>
		/// <param name="XmlDivisionList" Type="XmlDocument"/>
		/// <param name="SelectedDivision" Type="System.String"/>
		public Security(XmlDocument XmlSecurity, XmlDocument XmlDivisionList, String SelectedDivision)
		{
			this.XmlDivisionList		= XmlDivisionList;
			this.XmlSecurity				= XmlSecurity;
			this.SelectedDivision		= SelectedDivision;
		}
		/// <summary>
		/// 
		/// </summary>
		/// <param name="PageName"></param>
		/// <param name="XmlDivisionList"></param>
		/// <param name="XmlSecurityList"></param>
		/// <param name="SelectedDivision"></param>
		/// <returns></returns>
		public static bool IsInRole(string PageName, XmlDocument XmlDivisionList, XmlDocument XmlSecurityList, String SelectedDivision)
		{
			Security security = new Security(XmlSecurityList, XmlDivisionList, SelectedDivision);
			return security.IsInRole(PageName);
		}
		/// <summary>
		/// 
		/// </summary>
		/// <param name="XPathNode"></param>
		/// <returns></returns>
		public bool IsInRole(XPathNodeIterator XPathNode)
		{
			//Get the data from the XPathNode
			string SecuredArea = XPathNode.Current.GetAttribute("SecureArea", string.Empty);
			string Name = XPathNode.Current.GetAttribute("DisplayText", string.Empty);
			return IsInRole(Name);
		}	

		private bool IsInRole(string PageName)
		{			
			//WriteLog("VSS", "Application", "IsInRole\nPageName:" + PageName + "\nXPath: Security/Menu//*[@Name='" + PageName + "']/Roles");
			//Get the relevant nodes from the Security List
			if(PageName == string.Empty)
				return true;
			else if(XmlSecurity.SelectSingleNode("Security/Menu//*[@Name='" + PageName + "']/Roles") == null)
			{
				return false;
			}
			else
			{
				XmlSecurityList = XmlSecurity.SelectSingleNode("Security/Menu//*[@Name='" + PageName + "']/Roles").ChildNodes;
			}

			//Get the relevant nodes form the Selected Divisions List
			if(SelectedDivision == string.Empty)
				return false;
			else
				XmlDivision = XmlDivisionList.SelectSingleNode("DivisionList/Division[@Id='" + SelectedDivision +"']").ChildNodes;

			foreach (XmlNode XmlDivisionRole in XmlDivision)
			{
				foreach(XmlNode XmlSecurityRole in XmlSecurityList)
				{
					if(XmlDivisionRole.Attributes != null && 
						XmlSecurityRole.Attributes != null)
					{
						if(XmlDivisionRole.Attributes.GetNamedItem("Name").Value == XmlSecurityRole.Attributes.GetNamedItem("Name").Value)
						{
							if(XmlSecurityRole.Attributes.GetNamedItem("Access").Value == "GRANT")
								return true;
						}
					}
				}
			}
			return false;
		}

		static void WriteLog(string sSource, string sLog, string sEvent)
		{
			if (!EventLog.SourceExists(sSource))
				EventLog.CreateEventSource(sSource,sLog);

			//EventLog.WriteEntry(sSource,sEvent);
			EventLog.WriteEntry(sSource, sEvent, EventLogEntryType.Warning, 234);
		}

		#region Section: Public Properties
		/// <summary>
		/// XmlSecurity Document
		/// </summary>
		public XmlDocument XmlSecurity
		{
			get{ return xmlSecurity; }
			set{ xmlSecurity = value; }
		}
		/// <summary>
		/// XmlDivisionList Property
		/// </summary>
		public XmlDocument XmlDivisionList
		{
			get{ return xmlDivisionList; }
			set{ xmlDivisionList = value; }
		}
		/// <summary>
		/// SelectedDivision String
		/// </summary>
		public string SelectedDivision
		{
			get{ return selectedDivision; }
			set{ selectedDivision = value; }
		}
		#endregion
	}
}
